/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call.script;

import static dk.vajhoej.vms.call.lib.VMSStatus.*;

import java.io.UnsupportedEncodingException;

import dk.vajhoej.vms.call.lib.LIBRTL_Util;

/**
 * Class LIBRTL_Script is a script friendly wrapper library for LIB$ functions.
 */
public class LIBRTL_Script extends LIBRTL_Util {
	/**
	 * Call LIB$GETDVI to get single item as int.
	 * @param code item code
	 * @param devnam device name
	 * @return return status code + int value
	 * @throws UnsupportedEncodingException if device name can not be encoded
	 */
	public static Result<Integer> LIB$GETDVI_AsInt(String code, String devnam) throws UnsupportedEncodingException {
		int numcode = VMSCodesNames.nameToNumber("DVI$", code);
		if(numcode > 0) {
			return LIB$GETDVI_AsInt(numcode, devnam);
		} else {
			return new Result<Integer>(SS$_BADPARAM, 0);
		}
	}
	/**
	 * Call LIB$GETDVI to get single item as String.
	 * @param code item code
	 * @param devnam device name
	 * @return return status code + String value
	 * @throws UnsupportedEncodingException if device name can not be encoded or value can not be decoded
	 */
	public static Result<String> LIB$GETDVI_AsString(String code, String devnam) throws UnsupportedEncodingException {
		int numcode = VMSCodesNames.nameToNumber("DVI$", code);
		if(numcode > 0) {
			return LIB$GETDVI_AsString(numcode, devnam);
		} else {
			return new Result<String>(SS$_BADPARAM, "");
		}
	}
	/**
	 * Call LIB$GETJPI to get single item as int.
	 * @param code item code
	 * @param pid PID
	 * @return return status code + int value
	 * @throws UnsupportedEncodingException will never happen
	 */
	public static Result<Integer> LIB$GETJPI_AsInt(String code, int pid) throws UnsupportedEncodingException {
		int numcode = VMSCodesNames.nameToNumber("JPI$", code);
		if(numcode > 0) {
			return LIB$GETJPI_AsInt(numcode, pid);
		} else {
			return new Result<Integer>(SS$_BADPARAM, 0);
		}
	}
	/**
	 * Call LIB$GETJPI to get single item as String.
	 * @param code item code
	 * @param pid PID
	 * @return return status code + String value
	 * @throws UnsupportedEncodingException if value can not be decoded
	 */
	public static Result<String> LIB$GETJPI_AsString(String code, int pid) throws UnsupportedEncodingException {
		int numcode = VMSCodesNames.nameToNumber("JPI$", code);
		if(numcode > 0) {
			return LIB$GETJPI_AsString(numcode, pid);
		} else {
			return new Result<String>(SS$_BADPARAM, "");
		}
	}
    /**
     * Class TIMER_CTX represent context for LIB$INIT_TIMER and LIB$STAT_TIMER calls.
     */
	public static class TIMER_CTX extends dk.vajhoej.vms.call.lib.LIBRTL.TIMER_CTX {
		/**
		 * Call LIB$INIT_TIMER to start timer.
		 * @return return status code
		 */
		public Result<Void> LIB$INIT_TIMER() {
			return super.LIB$INIT_TIMER();
		}
		/**
		 * Call LIB$STAT_TIMER to get timer values.
		 * @param code code for timer value (TIM/CPUTIM/BIO/DIO/PF)
		 * @return return status code + timer value
		 */
		public Result<Integer> LIB$STAT_TIMER(String code) {
			int realcode;
			if(code.equals("TIM")) {
				realcode = 1;
			} else if(code.equals("CPUTIM")) {
				realcode = 2;
			} else if(code.equals("BIO")) {
				realcode = 3;
			} else if(code.equals("DIO")) {
				realcode = 4;
			} else if(code.equals("PF")) {
				realcode = 5;
			} else {
				realcode = 0;
			}
			return LIB$STAT_TIMER(realcode);
		}
	}
}
