/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call.script.py;

import java.io.UnsupportedEncodingException;
import java.util.List;
import java.util.Map;

import dk.vajhoej.record.RecordException;
import dk.vajhoej.vms.call.IOSB;
import dk.vajhoej.vms.call.VMS.Block;
import dk.vajhoej.vms.call.VMS.TypeWrapper;
import dk.vajhoej.vms.call.VMS.Word;
import dk.vajhoej.vms.call.script.SYS_Script;

/**
 * Class SYS_Py is a Python friendly wrapper library for system services (SYS$ functions).
 */
public class SYS_Py extends SYS_Script {
	/**
	 * Call SYS$ALLOC to allocate device.
	 * @param devnam device name
	 * @return return status code
	 * @throws UnsupportedEncodingException if device name can not be decoded
	 */
	public static Result<Void> SYS__ALLOC(String devnam) throws UnsupportedEncodingException {
		return SYS$ALLOC(devnam);
	}
	/**
	 * Call SYS$ASCTOID to get identifier for text name.
	 * @param name name
	 * @return status code + identifier
	 * @throws UnsupportedEncodingException if name string can not be decoded
	 */
	public static Result<Integer> SYS__ASCTOID(String name) throws UnsupportedEncodingException {
		return SYS$ASCTOID(name);
	}
	/**
	 * Call SYS$ASCTIM to get string with current time.
	 * @return return status code + string with time
	 * @throws UnsupportedEncodingException if time string can not be decoded
	 */
	public static Result<String> SYS__ASCTIM() throws UnsupportedEncodingException {
		return SYS$ASCTIM();
	}
	/**
	 * Call SYS$ASCTIM to get string with specified time.
	 * @param t VMS time
	 * @return return status code + string with time
	 * @throws UnsupportedEncodingException if time string can not be decoded
	 */
	public static Result<String> SYS__ASCTIM(long t) throws UnsupportedEncodingException {
		return SYS$ASCTIM(t);
	}
	/**
	 * Call SYS$ASSIGN to open channel to device.
	 * @param devnam device name
	 * @return return status code + channel
	 * @throws UnsupportedEncodingException if device name can not be decoded
	 */
	public static Result<Word> SYS__ASSIGN(String devnam) throws UnsupportedEncodingException {
		return SYS$ASSIGN(devnam);
	}
	/**
	 * Call SYS$BINTIM to get specified VMS time.
	 * @param timstr time string
	 * @return return status code + VMS time
	 * @throws UnsupportedEncodingException if time string can not be encoded
	 */
	public static Result<Long> SYS__BINTIM(String timstr) throws UnsupportedEncodingException {
		return SYS$BINTIM(timstr);
	}
	/**
	 * Call SYS$BRKTHRUW to send message to terminals.
	 * @param msg message
	 * @param terminal terminal (*=all)
	 * @return return status code
	 * @throws RecordException if internal error
	 * @throws UnsupportedEncodingException if message or terminal can not be encoded
	 */
	public static Result<Void> SYS__BRKTHRUW_terminal(String msg, String terminal) throws UnsupportedEncodingException, RecordException {
		return SYS$BRKTHRUW_terminal(msg, terminal);
	}
	/**
	 * Call SYS$BRKTHRUW to send message to users.
	 * @param msg message
	 * @param user username (*=all)
	 * @return return status code
	 * @throws RecordException if internal error
	 * @throws UnsupportedEncodingException if message or username can not be encoded
	 */
	public static Result<Void> SYS__BRKTHRUW_user(String msg, String user) throws UnsupportedEncodingException, RecordException {
		return SYS$BRKTHRUW_user(msg, user);
	}
	/**
	 * Call SYS$CRELNM to create logical name.
	 * @param flag logical name attribute
	 * @param tblnam logical table name
	 * @param lognam logical name
	 * @param acmode access mode
	 * @param logval logical values
	 * @return return status code
	 * @throws UnsupportedEncodingException if logical table name or logical name or logical vale can not be encoded
	 */
	public static Result<Void> SYS__CRELNM(int flag, String tblnam, String lognam, int acmode, String[] logval) throws UnsupportedEncodingException {
		return SYS$CRELNM(flag, tblnam, lognam, acmode, logval);
	}
	/**
	 * Call SYS$CRELNM to create logical name.
	 * @param tblnam logical table name
	 * @param lognam logical name
	 * @param logval logical value
	 * @return return status code
	 * @throws UnsupportedEncodingException if logical table name or logical name or logical vale can not be encoded
	 */
	public static Result<Void> SYS__CRELNM(String tblnam, String lognam, String logval) throws UnsupportedEncodingException {
		return SYS$CRELNM(tblnam, lognam, logval);
	}
	/**
	 * Call SYS$CREMBX to create mailbox.
	 * @param perm permanent flag, true =&gt; permanent, false =&gt; temporary
	 * @param maxmsg maximum message size
	 * @return return status code + channel to mailbox
	 */
	public static Result<Word> SYS__CREMBX(boolean perm, int maxmsg) {
		return SYS$CREMBX(perm, maxmsg);
	}
	/**
	 * Call SYS$DALLOC to deallocate device.
	 * @param devnam device name
	 * @return return status code
	 * @throws UnsupportedEncodingException if device name can not be decoded
	 */
	public static Result<Void> SYS__DALLOC(String devnam) throws UnsupportedEncodingException {
		return SYS$DALLOC(devnam);
	}
	/**
	 * Call SYS$CREPRC to start a process.
	 * @param image name of image to run
	 * @return return status code + PID of created process
	 * @throws UnsupportedEncodingException if image can not be encoded
	 */
	public static Result<Integer> SYS__CREPRC(String image) throws UnsupportedEncodingException {
		return SYS$CREPRC(image);
	}
	/**
	 * Call SYS$CREPRC to start a process.
	 * @param image name of image to run
	 * @param input SYS$INPUT
	 * @param output SYS$OUTPUT
	 * @return return status code + PID of created process
	 * @throws UnsupportedEncodingException if image can not be encoded
	 */
	public static Result<Integer> SYS__CREPRC(String image, String input, String output) throws UnsupportedEncodingException {
		return SYS$CREPRC(image, input, output);
	}
	/**
	 * Call SYS$CREPRC to start a process.
	 * @param image name of image to run
	 * @param input SYS$INPUT
	 * @param output SYS$OUTPUT
	 * @param error SYS$ERROR
	 * @return return status code + PID of created process
	 * @throws UnsupportedEncodingException if image can not be encoded
	 */
	public static Result<Integer> SYS__CREPRC(String image, String input, String output, String error) throws UnsupportedEncodingException {
		return SYS$CREPRC(image, input, output, error);
	}
	/**
	 * Call LIB$DASSGN to close channel.
	 * @param chan channel
	 * @return return status code
	 */
	public static Result<Void> SYS__DASSGN(Word chan) {
		return SYS$DASSGN(chan);
	}
	/**
	 * Call SYS$DELMBX to delete mailbox.
	 * @param chan channel to mailbox
	 * @return return status code
	 */
	public static Result<Void> SYS__DELMBX(Word chan) {
		return SYS$DELMBX(chan);
	}
	/**
	 * Call SYS$DEQ to release lock.
	 * @param lckid lock ID
	 * @return return status code
	 */
	public static Result<Void> SYS__DEQ(int lckid) {
		return SYS$DEQ(lckid);
	}
	/**
	 * Call SYS$ENQW to convert a lock.
	 * @param lckid lock ID
	 * @param mode lock mode
	 * @return return status code
	 * @throws RecordException if internal error
	 */
	public static Result<Void> SYS__ENQ(int lckid, String mode) throws RecordException {
		return SYS$ENQW(lckid, mode);
	}
	/**
	 * Call SYS$ENQW to take a lock.
	 * @param resnam resource name
	 * @param mode lock mode
	 * @return return status code + lock id
	 * @throws RecordException if internal error
	 * @throws UnsupportedEncodingException if resource name can not be encoded
	 */
	public static Result<Integer> SYS__ENQW(String resnam, String mode) throws RecordException, UnsupportedEncodingException {
		return SYS$ENQW(resnam, mode);
	}
	/**
	 * Exit program.
	 * @param code code to return to caller
	 * @return return status code (never used)
	 */
	public static Result<Void> SYS__EXIT(int code) {
		return SYS$EXIT(code);
	}
	/**
	 * Exit program of another process.
	 * @param pid PID
	 * @param code code to return to caller
	 * @return return status code
	 */
	public static Result<Void> SYS__FORCEX(int pid, int code) {
		return SYS$FORCEX(pid, code);
	}
	/**
	 * Call SYS$GETDVIW to get a list of items.
	 * @param devnam device name
	 * @param itms array of items
	 * @return return status code + Java Map with items
	 * @throws UnsupportedEncodingException if device name can not be encoded or some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static Result<Map<String,Object>> SYS__GETDVIW(String devnam, String[] itms) throws UnsupportedEncodingException, RecordException {
		return SYS$GETDVIW(devnam, itms);
	}
	/**
	 * Call SYS$GETDVIW to get a list of all items.
	 * @param devnam device name
	 * @return return status code + Java Map with items
	 * @throws UnsupportedEncodingException if device name can not be encoded or some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static Result<Map<String,Object>> SYS__GETDVIW(String devnam) throws UnsupportedEncodingException, RecordException {
		return SYS$GETDVIW(devnam);
	}
	/**
	 * Call SYS$GETJPIW to get a list of items.
	 * @param pid PID
	 * @param itms array of items
	 * @return return status code + Java Map with items
	 * @throws UnsupportedEncodingException if some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static Result<Map<String,Object>> SYS__GETJPIW(int pid, String[] itms) throws UnsupportedEncodingException, RecordException {
		return SYS$GETJPIW(pid, itms);
	}
	/**
	 * Call SYS$GETJPIW to get a list of all items.
	 * @param pid PID
	 * @return return status code + Java Map with items
	 * @throws UnsupportedEncodingException if some string values can not be encoded
	 * @throws RecordException if internal error
	 */
	public static Result<Map<String,Object>> SYS__GETJPIW(int pid) throws UnsupportedEncodingException, RecordException {
		return SYS$GETJPIW(pid);
	}
    /**
     * Call SYS$GETMSG to get message text for error code.
     * @param msgid error code
     * @return return status code + message text
     * @throws UnsupportedEncodingException if message text can not be decoded
     */
	public static Result<String> SYS__GETMSG(int msgid) throws UnsupportedEncodingException {
		return SYS$GETMSG(msgid);
	}
	/**
	 * Call SYS$GETQUIW to get information about entry.
	 * @param entry entry number
	 * @param itms array of items
	 * @return status code + Java Map of items
	 * @throws UnsupportedEncodingException if some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static Result<Map<String,Object>> SYS__GETQUIW_Entry(int entry,String[] itms) throws UnsupportedEncodingException, RecordException {
		return SYS$GETQUIW_Entry(entry, itms);
	}
	/**
	 * Call SYS$GETQUIW to get information about queue.
	 * @param queuename queue name
	 * @param itms array of items
	 * @return status code + Java Map of items
	 * @throws UnsupportedEncodingException if queue name can not be encoded or some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static Result<Map<String,Object>> SYS__GETQUIW_Queue(String queuename, String[] itms) throws UnsupportedEncodingException, RecordException {
		return SYS$GETQUIW_Queue(queuename, itms);
	}
	/**
	 * Call SYS$GETQUIW to get list of all jobs and information about them.
	 * @param queuename queue name
	 * @param itms array of items
	 * @return Java List of Java Map with items
	 * @throws UnsupportedEncodingException if error encoding queue name or decoding value
	 * @throws RecordException of internal error
	 */
	public static List<Map<String,Object>> SYS__GETQUIW_QueueJobs(String queuename, String[] itms) throws UnsupportedEncodingException, RecordException {
		return SYS$GETQUIW_QueueJobs(queuename, itms);
	}
	/**
	 * Call SYS$GETSYIW to get information about system.
	 * @param nodename node name
	 * @param itms array of items
	 * @return status code + Java Map of items
	 * @throws UnsupportedEncodingException if some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static Result<Map<String,Object>> SYS__GETSYIW(String nodename, String[] itms) throws UnsupportedEncodingException, RecordException {
		return SYS$GETSYIW(nodename, itms);
	}
	/**
	 * Call SYS$GETSYIW to get information about system.
	 * @param itms array of items
	 * @return status code + Java Map of items
	 * @throws UnsupportedEncodingException if some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static Result<Map<String,Object>> SYS$GETSYIW(String[] itms) throws UnsupportedEncodingException, RecordException {
		return SYS$GETSYIW(itms);
	}
	/**
	 * Call SYS$GETUAI to get a list of items.
	 * @param usrnam username
	 * @param itms array of items
	 * @return return status code +  Java Map with items
	 * @throws UnsupportedEncodingException if username can not be encoded or some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static Result<Map<String,Object>> SYS__GETUAI(String usrnam, String[] itms) throws UnsupportedEncodingException, RecordException {
		return SYS$GETUAI(usrnam, itms);
	}
	/**
	 * Call SYS$GETUAI to get a list of all items.
	 * @param usrnam username
	 * @return return status code +  Java Map with items
	 * @throws UnsupportedEncodingException if username can not be encoded or some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static Result<Map<String,Object>> SYS__GETUAI(String usrnam) throws UnsupportedEncodingException, RecordException {
		return SYS$GETUAI(usrnam);
	}
	/**
	 * Call SYS$HIBER to hibernate.
	 * @return return status code
	 */
	public static Result<Void> SYS__HIBER() {
        return SYS$HIBER();
	}
	/**
	 * Call SYS$IDTOASC to get name for identifier.
	 * @param id identifier
	 * @return return status code + identifier name
	 * @throws UnsupportedEncodingException if identifier name can not be decoded
	 */
	public static Result<String> SYS__IDTOASC(int id) throws UnsupportedEncodingException {
		return SYS$IDTOASC(id);
	}
	/**
	 * Class ID_CTX represents the context for SYS$IDTOASC calls.
	 */
	public static class ID_CTX extends dk.vajhoej.vms.call.lib.SYS.ID_CTX {
		/**
		 * Call SYS$IDTOASC to return next identifier.
		 * @return return status code + identifier
		 * @throws UnsupportedEncodingException if some identifier names can not be decoded
		 */
		public Result<Pair<Integer, String>> SYS__IDTOASC() throws UnsupportedEncodingException {
			return SYS$IDTOASC();
		}
	}
	/**
	 * Call SYS$IDTOASC to get map of identifiers to identifier names.
	 * @param inclneg include negative (identifiers that are not UIC's)
	 * @return map of identifiers to identifier names
	 * @throws UnsupportedEncodingException if some identifier names can not be decoded
	 */
	public static Map<Integer,String> SYS__IDTOASC(boolean inclneg) throws UnsupportedEncodingException {
		return SYS$IDTOASC(inclneg);
	}
	/**
	 * Call SYS$IDTOASC to get list of all identifiers.
	 * @param inclneg include negative (identifiers that are not UIC's)
	 * @return list of all identifiers
	 * @throws UnsupportedEncodingException if some string values can not be encoded
	 */
	public static List<String> SYS__IDTOASC_AsList(boolean inclneg) throws UnsupportedEncodingException {
		return SYS$IDTOASC_AsList(inclneg);
	}
	/**
	 * Call SYS$PROCESS_SCAN to get first matching PID.
	 * @param code code for SYS$PROCESS_SCAN
	 * @param value value for SYS$PROCESS_SCAN
	 * @return return status code + PID
	 * @throws UnsupportedEncodingException if value can not be encoded
	 */
	public static Result<Integer> SYS__PROCESS_SCAN(int code, String value) throws UnsupportedEncodingException {
		return SYS$PROCESS_SCAN(code, value);
	}
	/**
	 * Call SYS$PROCESS_SCAN to get all PID's and call SYS$GETJPIW for each PID to get list of items.
	 * @param code code for SYS$PROCESS_SCAN
	 * @param value value for SYS$PROCESS_SCAN
	 * @param itms array of items
	 * @return Java List of Java Map with items
	 * @throws UnsupportedEncodingException if value can not ne encoded or some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static List<Map<String,Object>> SYS__PROCESS_SCAN_and_SYS__GETJPIW_AsList(String code, String value, String[] itms) throws UnsupportedEncodingException, RecordException {
		return SYS$PROCESS_SCAN_and_SYS$GETJPIW_AsList(code, value, itms);
	}
	/**
	 * Call SYS$PROCESS_SCAN to get all PID's and call SYS$GETJPIW for each PID to get list of all items.
	 * @param code code for SYS$PROCESS_SCAN
	 * @param value value for SYS$PROCESS_SCAN
	 * @return Java List of Java Map with items
	 * @throws UnsupportedEncodingException if value can not be encoded or some string values can not be decoded
	 * @throws RecordException if internal error
	 */
	public static List<Map<String,Object>> SYS__PROCESS_SCAN_and_SYS__GETJPIW_AsList(String code, String value) throws UnsupportedEncodingException, RecordException {
		return SYS$PROCESS_SCAN_and_SYS$GETJPIW_AsList(code, value);
	}
	/**
	 * Call SYS$QIOW.
	 * @param chan channel
	 * @param func function
	 * @param iosb IOSB
	 * @param p1 p1
	 * @param p2 p2
	 * @return return status code
	 * @throws RecordException if internal error
	 * @throws UnsupportedEncodingException if something can not be encoded or decoded
	 */
	public static Result<Void> SYS__QIOW(Word chan, int func, Block<IOSB> iosb, TypeWrapper<byte[]> p1, TypeWrapper<Integer> p2) throws RecordException, UnsupportedEncodingException {
		return SYS$QIOW(chan, func, iosb, p1, p2);
	}
	/**
	 * Call SYS$SETDDIR to get current default directory.
	 * @return return status code + current default directory
	 * @throws UnsupportedEncodingException if directory can not be decoded
	 */
	public static Result<String> SYS__SETDDIR() throws UnsupportedEncodingException {
		return SYS$SETDDIR();
	}
	/**
	 * Call SYS$SETDDIR to change current default directory.
	 * @param newdir new default directory
	 * @return return status code
	 * @throws UnsupportedEncodingException if directory can not be encoded
	 */
	public static Result<Void> SYS__SETDDIR(String newdir) throws UnsupportedEncodingException {
		return SYS$SETDDIR(newdir);
	}
	/**
	 * Call SYS$SETPRI to set process priority.
	 * @param pri priority
	 * @return return status code
	 */
	public static Result<Void> SYS__SETPRI(int pri) {
		return SYS$SETPRI(pri);
	}
	/**
	 * Call SYS$SETPRI to set process priority.
	 * @param pid PID
	 * @param pri priority
	 * @return return status code
	 */
	public static Result<Void> SYS__SETPRI(int pid, int pri) {
		return SYS$SETPRI(pid, pri);
	}
	/**
	 * Call SYS$SETPRN to change process name of current process.
	 * @param prcnam process name
	 * @return return status code
	 * @throws UnsupportedEncodingException if process name can not be encoded
	 */
	public static Result<Void> SYS__SETPRN(String prcnam) throws UnsupportedEncodingException {
		return SYS$SETPRN(prcnam);
	}
	/**
	 * Call SYS$SETPRV to get current privs.
	 * @return return status code + current privs mask
	 */
	public static Result<Long> SYS__SETPRV() {
		return SYS$SETPRV();
	}
	/**
	 * Call SYS$SETPRV to change current privs.
	 * @param enable true=enable privs, false=disable privs
	 * @param privmask priv mask
	 * @param perm true=permanent for process, false=only for program run
	 * @return return status code
	 */
	public static Result<Void> SYS__SETPRV(boolean enable, long privmask, boolean perm) {
		return SYS$SETPRV(enable, privmask, perm);
	}
	/**
	 * Call SYS$SNDJBCW to submit batch job to batch queue.
	 * @param queuename batch queue name
	 * @param filename file name
	 * @return return status code + job entry number
	 * @throws RecordException if internal error
	 * @throws UnsupportedEncodingException if error encoding queuename or filename
	 */
	public static Result<Integer> SYS__SNDJBCW_Submit(String queuename, String filename) throws RecordException, UnsupportedEncodingException {
		return SYS$SNDJBCW_Submit(queuename, filename);
	}
	/**
	 * Call SYS$SNDJBCW to submit print job to print queue.
	 * @param queuename print queue name
	 * @param filename file name
	 * @return return status code + job entry number
	 * @throws RecordException if internal error
	 * @throws UnsupportedEncodingException if error encoding queuename or filename
	 */
	public static Result<Integer> SYS__SNDJBCW_Print(String queuename, String filename) throws RecordException, UnsupportedEncodingException {
		return SYS$SNDJBCW_Print(queuename, filename);
	}
	/**
	 * Class TERMINAL_IO represents the context (actually channel) for SYS$ASSIGN, SYS$QIOW and SYSDASSGN calls for terminal IO.
	 */
	public static class TERMINAL_IO extends dk.vajhoej.vms.call.lib.SYS.TERMINAL_IO {
		/**
		 * Call SYS$ASSIGN to open channel to default terminal (TT:).
		 * @return return status code
		 * @throws UnsupportedEncodingException if device name can not be encoded
		 */
		public Result<Void> SYS__ASSIGN() throws UnsupportedEncodingException {
			return SYS$ASSIGN();
		}
		/**
		 * Call SYS$ASSIGN to open channel to specified terminal.
		 * @param devnam terminal name
		 * @return return status code
		 * @throws UnsupportedEncodingException if device name can not be encoded
		 */
		public Result<Void> SYS__ASSIGN(String devnam) throws UnsupportedEncodingException {
			return SYS$ASSIGN(devnam);
		}
		/**
		 * Call SYS$QIOW to write string to terminal (puts functionality).
		 * @param s string to write
		 * @return return status code
		 * @throws RecordException if internal error
		 * @throws UnsupportedEncodingException if string can not be encoded
		 */
		public Result<Void> SYS__QIOW_puts(String s) throws RecordException, UnsupportedEncodingException {
			return SYS$QIOW_puts(s);
		}
		/**
		 * Call SYS$QIOW to read line from terminal (gets functionality).
		 * @return return status code + string read 
		 * @throws RecordException if internal error
		 * @throws UnsupportedEncodingException if string can not be decoded
		 */
		public Result<String> SYS__QIOW_gets() throws RecordException, UnsupportedEncodingException {
			return SYS$QIOW_gets();
		}
		/**
		 * Call SYS$QIOW to read single character from terminal (getch functionality).
		 * @return return status code + character read 
		 * @throws RecordException if internal error
		 * @throws UnsupportedEncodingException will never happen
		 */
		public Result<Character> SYS__QIOW_getch() throws RecordException, UnsupportedEncodingException {
			return SYS$QIOW_getch();
		}
		/**
		 * Call SYS$QIOW to check if there is input available to be read (kbhit functionality).
		 * @return  return status code + indication if input available
		 * @throws RecordException if internal error
		 * @throws UnsupportedEncodingException  will never happen
		 */
		public Result<Boolean> SYS__QIOW_kbhit() throws RecordException, UnsupportedEncodingException {
			return SYS$QIOW_kbhit();
		}
		/**
		 * Call LIB$DASSGN to close channel.
		 * @return return status code
		 */
		public Result<Void> SYS__DASSGN() {
			return SYS$DASSGN();
		}
	}
	/**
	 * Call SYS$TRNLNM to translate logical name.
	 * @param tblnam table name
	 * @param lognam logical name
	 * @return return status code + translate logical name
	 * @throws UnsupportedEncodingException if table or logical name can not be encoded or translation can not be decoded
	 */
	public static Result<String> SYS__TRNLNM(String tblnam, String lognam) throws UnsupportedEncodingException {
		return SYS$TRNLNM(tblnam, lognam);
	}
	/**
	 * Call SYS$TRNLNM to translate logical name and get attributes.
	 * @param tblnam table name
	 * @param lognam logical name
	 * @return return status code + translate logical name
	 * @throws UnsupportedEncodingException if table or logical name can not be encoded or translation can not be decoded
	 */
	public static Result<Pair<String,Integer>> SYS__TRNLNM_Attr(String tblnam, String lognam) throws UnsupportedEncodingException {
		return SYS$TRNLNM_Attr(tblnam, lognam);
	}
	/**
	 * Call SYS$TRNLNM to translate logical name.
	 * @param tblnam table name
	 * @param lognam logical name
	 * @param acmode access mode
	 * @param index logical name index
	 * @return return status code + translate logical name
	 * @throws UnsupportedEncodingException if table or logical name can not be encoded or translation can not be decoded
	 */
	public static Result<String> SYS__TRNLNM(String tblnam, String lognam, String acmode, int index) throws UnsupportedEncodingException {
		return SYS$TRNLNM(tblnam, lognam, acmode, index);
	}
	/**
	 * Call SYS$WAKE to wake up process.
	 * @return return status code
	 */
	public static Result<Void> SYS__WAKE() {
		return SYS$WAKE();
	}
	/**
	 * Call SYS$WAKE to wake up process.
	 * @param pid PID
	 * @return return status code
	 */
	public static Result<Void> SYS__WAKE(int pid) {
		return SYS$WAKE(pid);
	}
	/**
	 * Call SYS$WAKE to wake up process.
	 * @param prcnam process name
	 * @return return status code
	 * @throws UnsupportedEncodingException if process name can not be encoded
	 */
	public static Result<Void> SYS__WAKE(String prcnam) throws UnsupportedEncodingException {
		return SYS$WAKE(prcnam);
	}
}
